#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-pcre
version:              0.95.0.0
visibility:           public
id:                   regex-pcre-0.95.0.0-IRgTpqryQ3DLvKP9pgVgkA
key:                  regex-pcre-0.95.0.0-IRgTpqryQ3DLvKP9pgVgkA
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:           hvr@gnu.org
author:               Christopher Kuklewicz
synopsis:             PCRE Backend for "Text.Regex" (regex-base)
description:
    This package provides a <http://pcre.org/ PCRE> backend for the <//hackage.haskell.org/package/regex-base regex-base> API.

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  1d3efb325d6497e338d4e9330a905d77
exposed:              True
exposed-modules:
    Text.Regex.PCRE Text.Regex.PCRE.ByteString
    Text.Regex.PCRE.ByteString.Lazy Text.Regex.PCRE.Sequence
    Text.Regex.PCRE.String Text.Regex.PCRE.Wrap

hidden-modules:       Paths_regex_pcre
import-dirs:          /usr/lib/ghc-8.10.5/site-local/regex-pcre-0.95.0.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/regex-pcre-0.95.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/regex-pcre-0.95.0.0
hs-libraries:         HSregex-pcre-0.95.0.0-IRgTpqryQ3DLvKP9pgVgkA
extra-libraries:      pcre
depends:
    array-0.5.4.0 base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    regex-base-0.94.0.1-BhcrfAa0EaQLabAeJ8QV4e

haddock-interfaces:   /usr/share/doc/haskell-regex-pcre/html/regex-pcre.haddock
haddock-html:         /usr/share/doc/haskell-regex-pcre/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

